Create

Struct Create 

pub struct Create<'a> {
    pub funding_account: &'a AccountView,
    pub account: &'a AccountView,
    pub wallet: &'a AccountView,
    pub mint: &'a AccountView,
    pub system_program: &'a AccountView,
    pub token_program: &'a AccountView,
}
Creates an associated token account for the given wallet address and token mint. Returns an error if the account exists.

Accounts:

  1. [WRITE, SIGNER] Funding account (must be a system account)
  2. [WRITE] Associated token account address to be created
  3. [] Wallet address for the new associated token account
  4. [] The token mint for the new associated token account
  5. [] System program
  6. [] SPL Token program

Fields

funding_account: &'a AccountView

Funding account (must be a system account)

account: &'a AccountView

Associated token account address to be created

wallet: &'a AccountView

Wallet address for the new associated token account

mint: &'a AccountView

The token mint for the new associated token account

system_program: &'a AccountView

System program

token_program: &'a AccountView

SPL Token program

Implementations

Source

impl Create<'_>

pub fn invoke(&self) -> Result<(), ProgramError>

pub fn invoke_signed( &self, signers: &[Signer<'_, '_>], ) -> Result<(), ProgramError>