RecoverNested

Struct RecoverNested 

pub struct RecoverNested<'a> {
    pub account: &'a AccountView,
    pub mint: &'a AccountView,
    pub destination_account: &'a AccountView,
    pub owner_account: &'a AccountView,
    pub owner_mint: &'a AccountView,
    pub wallet: &'a AccountView,
    pub token_program: &'a AccountView,
}
Transfers from and closes a nested associated token account: an associated token account owned by an associated token account.

The tokens are moved from the nested associated token account to the wallet’s associated token account, and the nested account lamports are moved to the wallet.

Note: Nested token accounts are an anti-pattern, and almost always created unintentionally, so this instruction should only be used to recover from errors

Accounts:

  1. [WRITE] Nested associated token account, must be owned by 3
  2. [] Token mint for the nested associated token account
  3. [WRITE] Wallet’s associated token account
  4. [] Owner associated token account address, must be owned by 5
  5. [] Token mint for the owner associated token account
  6. [WRITE, SIGNER] Wallet address for the owner associated token account
  7. [] SPL Token program

Fields

account: &'a AccountView

Nested associated token account, must be owned by owner_associated_token_account

mint: &'a AccountView

Token mint for the nested associated token account

destination_account: &'a AccountView

Wallet’s associated token account

owner_account: &'a AccountView

Owner associated token account address, must be owned by wallet_account

owner_mint: &'a AccountView

Token mint for the owner associated token account

wallet: &'a AccountView

Wallet address for the owner associated token account

token_program: &'a AccountView

SPL Token program

Implementations

Source

impl RecoverNested<'_>

pub fn invoke(&self) -> Result<(), ProgramError>

pub fn invoke_signed( &self, signers: &[Signer<'_, '_>], ) -> Result<(), ProgramError>