pub struct SetAuthority<'a> {
pub account: &'a AccountView,
pub authority: &'a AccountView,
pub authority_type: AuthorityType,
pub new_authority: Option<&'a Address>,
}Expand description
Sets a new authority of a mint or account.
Accounts:
[WRITE]The mint or account to change the authority of.[SIGNER]The current authority of the mint or account.
Fields
account: &'a AccountViewAccount (Mint or Token)
Authority of the Account.
The type of authority to update.
The new authority
Implementations
Sourceimpl SetAuthority<'_>
impl SetAuthority<'_>
pub fn invoke(&self) -> Result<(), ProgramError>
pub fn invoke_signed( &self, signers: &[Signer<'_, '_>], ) -> Result<(), ProgramError>