pub struct SyncNative<'a> {
pub native_token: &'a AccountView,
}Expand description
Given a native token account updates its amount field based
on the account’s underlying lamports.
Accounts:
[WRITE]The native token account to sync with its underlying lamports.
Fields
native_token: &'a AccountViewNative Token Account
Implementations
Sourceimpl SyncNative<'_>
impl SyncNative<'_>
pub fn invoke(&self) -> Result<(), ProgramError>