Mint

Struct Mint 

pub struct Mint(/* private fields */);

Implementations

Source

impl Mint

pub const LEN: usize = SplMint::LEN

Methods from Deref<Target = SplMint>

pub const LEN: usize

pub fn has_mint_authority(&self) -> bool

pub fn mint_authority(&self) -> Option<&Address>

pub fn mint_authority_unchecked(&self) -> &Address

Return the mint authority.

This method should be used when the caller knows that the mint will have a mint authority set since it skips the Option check.

pub fn supply(&self) -> u64

pub fn decimals(&self) -> u8

pub fn is_initialized(&self) -> bool

pub fn has_freeze_authority(&self) -> bool

pub fn freeze_authority(&self) -> Option<&Address>

pub fn freeze_authority_unchecked(&self) -> &Address

Return the freeze authority.

This method should be used when the caller knows that the mint will have a freeze authority set since it skips the Option check.