pub struct Mint(/* private fields */);Implementations
Methods from Deref<Target = SplMint>
pub const LEN: usize
Return the mint authority.
This method should be used when the caller knows that the mint will have a mint
authority set since it skips the Option check.
pub fn supply(&self) -> u64
pub fn decimals(&self) -> u8
pub fn is_initialized(&self) -> bool
Return the freeze authority.
This method should be used when the caller knows that the mint will have a freeze
authority set since it skips the Option check.